@@ -1,6 +1,5 @@
-/* $Id: hparser.c,v 2.129 2006/04/27 11:44:00 gisle Exp $
- *
- * Copyright 1999-2006, Gisle Aas
+/* 
+ * Copyright 1999-2008, Gisle Aas
  * Copyright 1999-2000, Michael A. Chase
  *
  * This library is free software; you can redistribute it and/or
@@ -26,6 +25,7 @@ literal_mode_elem[] =
     {6, "script", 1},
     {5, "style", 1},
     {3, "xmp", 1},
+    {6, "iframe", 1},
     {9, "plaintext", 1},
     {5, "title", 0},
     {8, "textarea", 0},
@@ -455,7 +455,7 @@ report_event(PSTATE* p_state,
 		    if (tokens[i+1].beg) {
 			char *beg = tokens[i+1].beg;
 			STRLEN len = tokens[i+1].end - beg;
-			if (*beg == '"' || *beg == '\'') {
+			if (*beg == '"' || *beg == '\'' || (*beg == '`' && p_state->backquote)) {
 			    assert(len >= 2 && *beg == beg[len-1]);
 			    beg++; len -= 2;
 			}
@@ -1142,6 +1142,8 @@ parse_decl(PSTATE* p_state, char *beg, char *end, U32 utf8, SV* self)
 	while (s < end && isHNAME_CHAR(*s))
 	    s++;
 	decl_id_len = s - decl_id;
+	if (s == end)
+	    goto PREMATURE;
 
 	/* just hardcode a few names as the recognized declarations */
 	if (!((decl_id_len == 7 &&
@@ -1157,15 +1159,14 @@ parse_decl(PSTATE* p_state, char *beg, char *end, U32 utf8, SV* self)
 	/* first word available */
 	PUSH_TOKEN(decl_id, s);
 
-	while (s < end && isHSPACE(*s)) {
-	    s++;
+	while (1) {
 	    while (s < end && isHSPACE(*s))
 		s++;
 
 	    if (s == end)
 		goto PREMATURE;
 
-	    if (*s == '"' || *s == '\'') {
+	    if (*s == '"' || *s == '\'' || (*s == '`' && p_state->backquote)) {
 		char *str_beg = s;
 		s++;
 		while (s < end && *s != *str_beg)
@@ -1239,7 +1240,8 @@ DECL_FAIL:
 	return 0;
 
     /* consider everything up to the first '>' a comment */
-    s = skip_until_gt(s, end);
+    while (s < end && *s != '>')
+	s++;
     if (s < end) {
 	token_pos_t token;
 	token.beg = beg + 2;
@@ -1335,7 +1337,7 @@ parse_start(PSTATE* p_state, char *beg, char *end, U32 utf8, SV* self)
 		PUSH_TOKEN(s, s);
 		break;
 	    }
-	    if (*s == '"' || *s == '\'') {
+	    if (*s == '"' || *s == '\'' || (*s == '`' && p_state->backquote)) {
 		char *str_beg = s;
 		s++;
 		while (s < end && *s != *str_beg)
@@ -1381,10 +1383,10 @@ parse_start(PSTATE* p_state, char *beg, char *end, U32 utf8, SV* self)
 	s++;
 	/* done */
 	report_event(p_state, E_START, beg, s, utf8, tokens, num_tokens, self);
-	if (empty_tag)
+	if (empty_tag) {
 	    report_event(p_state, E_END, s, s, utf8, tokens, 1, self);
-
-	if (!p_state->xml_mode) {
+	}
+	else if (!p_state->xml_mode) {
 	    /* find out if this start tag should put us into literal_mode
 	     */
 	    int i;
@@ -1546,29 +1548,9 @@ parse_buf(pTHX_ PSTATE* p_state, char *beg, char *end, U32 utf8, SV* self)
 
 	while (p_state->literal_mode) {
 	    char *l = p_state->literal_mode;
-	    bool skip_quoted_end = (strEQ(l, "script") || strEQ(l, "style"));
-	    char inside_quote = 0;
-	    bool escape_next = 0;
 	    char *end_text;
 
-	    while (s < end) {
-		if (*s == '<' && !inside_quote)
-		    break;
-		if (skip_quoted_end) {
-		    if (escape_next) {
-			escape_next = 0;
-		    }
-		    else {
-			if (*s == '\\')
-			    escape_next = 1;
-			else if (inside_quote && *s == inside_quote)
-			    inside_quote = 0;
-			else if (*s == '\r' || *s == '\n')
-			    inside_quote = 0;
-			else if (!inside_quote && (*s == '"' || *s == '\''))
-			    inside_quote = *s;
-		    }
-		}
+	    while (s < end && *s != '<') {
 		s++;
 	    }
 
@@ -1757,9 +1739,27 @@ parse(pTHX_
 
 	    while (s < end) {
 		if (p_state->literal_mode) {
-		    if (strEQ(p_state->literal_mode, "plaintext") && !p_state->closing_plaintext)
+		    if (strEQ(p_state->literal_mode, "plaintext") ||
+			strEQ(p_state->literal_mode, "xmp") ||
+			strEQ(p_state->literal_mode, "iframe") ||
+			strEQ(p_state->literal_mode, "textarea"))
+		    {
+			/* rest is considered text */
 			break;
-		    p_state->pending_end_tag = p_state->literal_mode;
+                    }
+		    if (strEQ(p_state->literal_mode, "script") ||
+			strEQ(p_state->literal_mode, "style"))
+		    {
+			/* effectively make it an empty element */
+			token_pos_t t;
+			char dummy;
+			t.beg = p_state->literal_mode;
+			t.end = p_state->literal_mode + strlen(p_state->literal_mode);
+			report_event(p_state, E_END, &dummy, &dummy, 0, &t, 1, self);
+		    }
+		    else {
+			p_state->pending_end_tag = p_state->literal_mode;
+		    }
 		    p_state->literal_mode = 0;
 		    s = parse_buf(aTHX_ p_state, s, end, utf8, self);
 		    continue;
@@ -1772,12 +1772,15 @@ parse(pTHX_
 		}
 
 		if (!p_state->strict_comment && *s == '<') {
-		    /* some kind of unterminated markup.  Report rest as as comment */
-		    token_pos_t token;
-		    token.beg = s + 1;
-		    token.end = end;
-		    report_event(p_state, E_COMMENT, s, end, utf8, &token, 1, self);
-		    s = end;
+		    char *s1 = s + 1;
+		    if (s1 == end || isHNAME_FIRST(*s1) || *s1 == '/' || *s1 == '!' || *s1 == '?') {
+			/* some kind of unterminated markup.  Report rest as as comment */
+			token_pos_t token;
+			token.beg = s + 1;
+			token.end = end;
+			report_event(p_state, E_COMMENT, s, end, utf8, &token, 1, self);
+			s = end;
+		    }
 		}
 
 		break;
