@@ -1,6 +1,5 @@
-/* $Id: hparser.h,v 2.31 2004/11/23 20:38:27 gisle Exp $
- *
- * Copyright 1999-2004, Gisle Aas
+/* 
+ * Copyright 1999-2005, Gisle Aas
  * Copyright 1999-2000, Michael A. Chase
  *
  * This library is free software; you can redistribute it and/or
@@ -70,6 +69,7 @@ struct p_state {
     STRLEN offset;
     STRLEN line;
     STRLEN column;
+    bool start_document;
     bool parsing;
     bool eof;
 
@@ -106,6 +106,9 @@ struct p_state {
     bool case_sensitive;
     bool closing_plaintext;
     bool utf8_mode;
+    bool empty_element_tags;
+    bool xml_pic;
+    bool backquote;
 
     /* other configuration stuff */
     SV* bool_attr_val;
